Module subproof

Module subproof 

Types and methods for subproof verification inside the crate::Executor.

Structs

NoOpSubproofVerifier
A dummy verifier which does nothing.

Traits

SubproofVerifier
Verifier used in runtime when monerochan_runtime::precompiles::verify::verify_monerochan_proof is called. This is then used to sanity check that the user passed in the correct proof; the actual constraints happen in the recursion layer.